@@ -19,7 +19,7 @@ try:
 except:
 	from halo import Halo
 
-from kxy.api import APIClient, upload_data, approx_opt_remaining_time
+from kxy.api import APIClient, upload_data
 
 # Cache old job ids to avoid being charged twice for the same job.
 DD_IMPROVABILITY_JOB_IDS = {}
